Jwt

Struct Jwt 

pub struct Jwt<C, H> { /* private fields */ }
The JSON Web Token This uses generics, for the claims and header, all that is required is that they are structs which implement Deserialize. See: What is a JSON Web Token

Implementations

Source

impl<C, H> Jwt<C, H>

pub fn new(claims: C, header: H) -> Jwt<C, H>

pub fn claims(&self) -> &C

pub fn header(&self) -> &H

Source

impl<Claims, Header> Jwt<Claims, Header>
where Claims: Serialize, Header: Serialize,

pub fn to_string(&self) -> Result<String, Error>